import { useContext } from "react";
import { useMount } from "utils-hooks";
import { TabPanelContext } from "./TabPanelContext";
import { TabsContext } from "./TabsContext";
/**
 * tab面板激活事件
 * @param func
 */
export function useTabEnter(func) {
    var tabsContext = useContext(TabsContext);
    var panelContext = useContext(TabPanelContext);
    useMount(function () {
        // 懒加载模式下主动调用一次
        if (tabsContext.lazy || tabsContext.activeKey === panelContext.tabKey) {
            func();
        }
        tabsContext.enterEvents.set(panelContext.tabKey, func);
        return function () { return tabsContext.enterEvents.delete(panelContext.tabKey); };
    });
}
/**
 * tab面板离开事件
 * @param func
 */
export function useTabLeave(func) {
    var tabsContext = useContext(TabsContext);
    var panelContext = useContext(TabPanelContext);
    useMount(function () {
        tabsContext.leaveEvents.set(panelContext.tabKey, func);
        return function () { return tabsContext.leaveEvents.delete(panelContext.tabKey); };
    });
}
//# sourceMappingURL=hooks.js.map